@@ -36,12 +36,12 @@ _gsasl_anonymous_client_done (Gsasl_ctx * ctx)
 }
 
 int
-_gsasl_anonymous_client_start (Gsasl_session_ctx * cctx, void **mech_data)
+_gsasl_anonymous_client_start (Gsasl_session_ctx * sctx, void **mech_data)
 {
   Gsasl_ctx *ctx;
   int *step;
 
-  ctx = gsasl_client_ctx_get (cctx);
+  ctx = gsasl_client_ctx_get (sctx);
   if (ctx == NULL)
     return GSASL_CANNOT_GET_CTX;
 
@@ -60,7 +60,7 @@ _gsasl_anonymous_client_start (Gsasl_session_ctx * cctx, void **mech_data)
 }
 
 int
-_gsasl_anonymous_client_step (Gsasl_session_ctx * cctx,
+_gsasl_anonymous_client_step (Gsasl_session_ctx * sctx,
 			      void *mech_data,
 			      const char *input,
 			      size_t input_len,
@@ -76,7 +76,7 @@ _gsasl_anonymous_client_step (Gsasl_session_ctx * cctx,
 
   (*step)++;
 
-  ctx = gsasl_client_ctx_get (cctx);
+  ctx = gsasl_client_ctx_get (sctx);
   if (ctx == NULL)
     return GSASL_CANNOT_GET_CTX;
 
@@ -84,7 +84,7 @@ _gsasl_anonymous_client_step (Gsasl_session_ctx * cctx,
   if (cb_anonymous == NULL)
     return GSASL_NEED_CLIENT_ANONYMOUS_CALLBACK;
 
-  res = cb_anonymous (cctx, output, output_len);
+  res = cb_anonymous (sctx, output, output_len);
   if (res != GSASL_OK)
     return res;
 
@@ -92,7 +92,7 @@ _gsasl_anonymous_client_step (Gsasl_session_ctx * cctx,
 }
 
 int
-_gsasl_anonymous_client_finish (Gsasl_session_ctx * cctx, void *mech_data)
+_gsasl_anonymous_client_finish (Gsasl_session_ctx * sctx, void *mech_data)
 {
   int *step = mech_data;
 
