@@ -550,12 +550,16 @@ _gsasl_digest_md5_client_init (Gsasl_ctx * ctx)
 {
   int res;
 
-  if (gcry_check_version (GCRYPT_VERSION) == NULL)
-    return GSASL_GCRYPT_ERROR;
-
-  res = gcry_control (GCRYCTL_INIT_SECMEM, 512, 0);
-  if (res != GCRYERR_SUCCESS)
-    return GSASL_GCRYPT_ERROR;
+  if (gcry_control (GCRYCTL_ANY_INITIALIZATION_P) == 0)
+    {
+      if (gcry_check_version (GCRYPT_VERSION) == NULL)
+	return GSASL_GCRYPT_ERROR;
+      if (gcry_control (GCRYCTL_DISABLE_SECMEM, NULL, 0) != GCRYERR_SUCCESS)
+	return GSASL_GCRYPT_ERROR;
+      if (gcry_control(GCRYCTL_INITIALIZATION_FINISHED,
+		       NULL, 0) != GCRYERR_SUCCESS)
+	return GSASL_GCRYPT_ERROR;
+    }
 
   return GSASL_OK;
 }
@@ -567,12 +571,12 @@ _gsasl_digest_md5_client_done (Gsasl_ctx * ctx)
 }
 
 int
-_gsasl_digest_md5_client_start (Gsasl_session_ctx * cctx, void **mech_data)
+_gsasl_digest_md5_client_start (Gsasl_session_ctx * sctx, void **mech_data)
 {
   _Gsasl_digest_md5_client_state *state;
   Gsasl_ctx *ctx;
 
-  ctx = gsasl_client_ctx_get (cctx);
+  ctx = gsasl_client_ctx_get (sctx);
   if (ctx == NULL)
     return GSASL_CANNOT_GET_CTX;
 
@@ -602,7 +606,7 @@ _gsasl_digest_md5_client_start (Gsasl_session_ctx * cctx, void **mech_data)
 }
 
 int
-_gsasl_digest_md5_client_step (Gsasl_session_ctx * cctx,
+_gsasl_digest_md5_client_step (Gsasl_session_ctx * sctx,
 			       void *mech_data,
 			       const char *input,
 			       size_t input_len,
@@ -621,7 +625,7 @@ _gsasl_digest_md5_client_step (Gsasl_session_ctx * cctx,
   int outlen;
   int res, i;
 
-  ctx = gsasl_client_ctx_get (cctx);
+  ctx = gsasl_client_ctx_get (sctx);
   if (ctx == NULL)
     return GSASL_CANNOT_GET_CTX;
 
@@ -827,14 +831,14 @@ _gsasl_digest_md5_client_step (Gsasl_session_ctx * cctx,
 	    goto done;
 	  }
 	if (cb_qop)
-	  state->qop = cb_qop (cctx, state->qop);
+	  state->qop = cb_qop (sctx, state->qop);
 	else
 	  state->qop = state->qop;
 	if (cb_authorization_id)
 	  {
 	    size_t authzidlen;
 
-	    res = cb_authorization_id (cctx, NULL, &authzidlen);
+	    res = cb_authorization_id (sctx, NULL, &authzidlen);
 	    if (res != GSASL_OK)
 	      goto done;
 	    state->authzid = (char *) malloc (authzidlen + 1);
@@ -843,7 +847,7 @@ _gsasl_digest_md5_client_step (Gsasl_session_ctx * cctx,
 		res = GSASL_MALLOC_ERROR;
 		goto done;
 	      }
-	    res = cb_authorization_id (cctx, state->authzid, &authzidlen);
+	    res = cb_authorization_id (sctx, state->authzid, &authzidlen);
 	    if (res != GSASL_OK)
 	      goto done;
 	    state->authzid[authzidlen] = '\0';
@@ -852,7 +856,7 @@ _gsasl_digest_md5_client_step (Gsasl_session_ctx * cctx,
 	{
 	  int usernamelen;
 
-	  res = cb_authentication_id (cctx, NULL, &usernamelen);
+	  res = cb_authentication_id (sctx, NULL, &usernamelen);
 	  if (res != GSASL_OK)
 	    goto done;
 
@@ -867,7 +871,7 @@ _gsasl_digest_md5_client_step (Gsasl_session_ctx * cctx,
 	  strcat (output, USERNAME_PRE);
 	  outlen += strlen (USERNAME_PRE);
 
-	  res = cb_authentication_id (cctx, &output[outlen], &usernamelen);
+	  res = cb_authentication_id (sctx, &output[outlen], &usernamelen);
 	  if (res != GSASL_OK)
 	    goto done;
 	  outlen += usernamelen;
@@ -987,7 +991,7 @@ _gsasl_digest_md5_client_step (Gsasl_session_ctx * cctx,
 	  size_t servicenamelen = 0;
 	  size_t len;
 
-	  res = cb_service (cctx, NULL, &servicelen,
+	  res = cb_service (sctx, NULL, &servicelen,
 			    NULL, &hostnamelen, NULL, &servicenamelen);
 	  if (res != GSASL_OK)
 	    goto done;
@@ -999,7 +1003,7 @@ _gsasl_digest_md5_client_step (Gsasl_session_ctx * cctx,
 	      res = GSASL_MALLOC_ERROR;
 	      goto done;
 	    }
-	  res = cb_service (cctx, state->digesturi, &servicelen,
+	  res = cb_service (sctx, state->digesturi, &servicelen,
 			    state->digesturi + 1 + servicelen, &hostnamelen,
 			    (servicenamelen > 0 ?
 			     state->digesturi + 1 + servicelen + 1 +
@@ -1051,7 +1055,7 @@ _gsasl_digest_md5_client_step (Gsasl_session_ctx * cctx,
 	      goto done;
 	    }
 	  len = *output_len - outlen;
-	  res = cb_authentication_id (cctx, output + outlen, &len);
+	  res = cb_authentication_id (sctx, output + outlen, &len);
 	  if (res != GSASL_OK)
 	    goto done;
 
@@ -1063,7 +1067,7 @@ _gsasl_digest_md5_client_step (Gsasl_session_ctx * cctx,
 
 	  len = *output_len - outlen;
 	  /* XXX? password stored in callee's output buffer */
-	  res = cb_password (cctx, output + outlen, &len);
+	  res = cb_password (sctx, output + outlen, &len);
 	  if (res != GSASL_OK)
 	    goto done;
 	  tmp = stringprep_utf8_nfkc_normalize (output + outlen, len);
@@ -1106,7 +1110,7 @@ _gsasl_digest_md5_client_step (Gsasl_session_ctx * cctx,
 	  outlen += strlen (RESPONSE_POST);
 	}
 	if (cb_maxbuf
-	    && (maxbuf = cb_maxbuf (cctx, maxbuf)) != MAXBUF_DEFAULT)
+	    && (maxbuf = cb_maxbuf (sctx, maxbuf)) != MAXBUF_DEFAULT)
 	  {
 	    if (outlen + strlen (MAXBUF_PRE) +
 		/* XXX don't require -lm, how? */
@@ -1259,7 +1263,7 @@ _gsasl_digest_md5_client_step (Gsasl_session_ctx * cctx,
 }
 
 int
-_gsasl_digest_md5_client_finish (Gsasl_session_ctx * cctx, void *mech_data)
+_gsasl_digest_md5_client_finish (Gsasl_session_ctx * sctx, void *mech_data)
 {
   _Gsasl_digest_md5_client_state *state = mech_data;
 
@@ -1275,7 +1279,7 @@ _gsasl_digest_md5_client_finish (Gsasl_session_ctx * cctx, void *mech_data)
 }
 
 int
-_gsasl_digest_md5_client_encode (Gsasl_session_ctx * xctx,
+_gsasl_digest_md5_client_encode (Gsasl_session_ctx * sctx,
 				 void *mech_data,
 				 const char *input,
 				 size_t input_len,
@@ -1284,25 +1288,18 @@ _gsasl_digest_md5_client_encode (Gsasl_session_ctx * xctx,
   _Gsasl_digest_md5_client_state *state = mech_data;
   int res;
 
-  if (state == NULL || state->step != 3)
+  if (state && state->step == 3 && state->qop & GSASL_QOP_AUTH_CONF)
     {
-      *output_len = input_len;
-      if (output)
-	memcpy (output, input, input_len);
-      return GSASL_OK;
+      /* XXX */
     }
-
-  if (state->qop & GSASL_QOP_AUTH_CONF)
-    {
-
-    }
-  else if (state->qop & GSASL_QOP_AUTH_INT)
+  else if (state && state->step == 3 && state->qop & GSASL_QOP_AUTH_INT)
     {
       GCRY_MD_HD md5h;
       char *hash;
       uint32_t tmp;
 
-      if (MAC_DATA_LEN + input_len + MAC_HMAC_LEN +
+      if (output &&
+	  MAC_DATA_LEN + input_len + MAC_HMAC_LEN +
 	  MAC_MSG_TYPE_LEN + MAC_SEQNUM_LEN > *output_len)
 	return GSASL_TOO_SMALL_BUFFER;
 
@@ -1344,20 +1341,7 @@ _gsasl_digest_md5_client_encode (Gsasl_session_ctx * xctx,
 
       gcry_md_close (md5h);
     }
-
-  return GSASL_OK;
-}
-
-int
-_gsasl_digest_md5_client_decode (Gsasl_session_ctx * xctx,
-				 void *mech_data,
-				 const char *input,
-				 size_t input_len,
-				 char *output, size_t * output_len)
-{
-  _Gsasl_digest_md5_client_state *state = mech_data;
-
-  if (state == NULL || state->step != 3)
+  else
     {
       *output_len = input_len;
       if (output)
@@ -1365,11 +1349,23 @@ _gsasl_digest_md5_client_decode (Gsasl_session_ctx * xctx,
       return GSASL_OK;
     }
 
-  if (state->qop & GSASL_QOP_AUTH_CONF)
-    {
+  return GSASL_OK;
+}
 
+int
+_gsasl_digest_md5_client_decode (Gsasl_session_ctx * sctx,
+				 void *mech_data,
+				 const char *input,
+				 size_t input_len,
+				 char *output, size_t * output_len)
+{
+  _Gsasl_digest_md5_client_state *state = mech_data;
+
+  if (state && state->step == 3 && state->qop & GSASL_QOP_AUTH_CONF)
+    {
+      /* XXX */
     }
-  else if (state->qop & GSASL_QOP_AUTH_INT)
+  else if (state && state->step == 3 && state->qop & GSASL_QOP_AUTH_INT)
     {
       GCRY_MD_HD md5h;
       char *hash;
@@ -1426,6 +1422,14 @@ _gsasl_digest_md5_client_decode (Gsasl_session_ctx * xctx,
 
       gcry_md_close (md5h);
     }
+  else
+    {
+      *output_len = input_len;
+      if (output)
+	memcpy (output, input, input_len);
+      return GSASL_OK;
+    }
+
 
   return GSASL_OK;
 }
@@ -2114,7 +2118,7 @@ _gsasl_digest_md5_server_finish (Gsasl_session_ctx * sctx, void *mech_data)
 }
 
 int
-_gsasl_digest_md5_server_encode (Gsasl_session_ctx * xctx,
+_gsasl_digest_md5_server_encode (Gsasl_session_ctx * sctx,
 				 void *mech_data,
 				 const char *input,
 				 size_t input_len,
@@ -2123,25 +2127,18 @@ _gsasl_digest_md5_server_encode (Gsasl_session_ctx * xctx,
   _Gsasl_digest_md5_server_state *state = mech_data;
   int res;
 
-  if (state == NULL || state->step != 3)
+  if (state && state->step == 3 && state->qop & GSASL_QOP_AUTH_CONF)
     {
-      *output_len = input_len;
-      if (output)
-	memcpy (output, input, input_len);
-      return GSASL_OK;
+      /* XXX */
     }
-
-  if (state->qop & GSASL_QOP_AUTH_CONF)
-    {
-
-    }
-  else if (state->qop & GSASL_QOP_AUTH_INT)
+  else if (state && state->step == 3 && state->qop & GSASL_QOP_AUTH_INT)
     {
       GCRY_MD_HD md5h;
       char *hash;
       uint32_t tmp;
 
-      if (MAC_DATA_LEN + input_len + MAC_HMAC_LEN +
+      if (output &&
+	  MAC_DATA_LEN + input_len + MAC_HMAC_LEN +
 	  MAC_MSG_TYPE_LEN + MAC_SEQNUM_LEN > *output_len)
 	return GSASL_TOO_SMALL_BUFFER;
 
@@ -2183,20 +2180,7 @@ _gsasl_digest_md5_server_encode (Gsasl_session_ctx * xctx,
 
       gcry_md_close (md5h);
     }
-
-  return GSASL_OK;
-}
-
-int
-_gsasl_digest_md5_server_decode (Gsasl_session_ctx * xctx,
-				 void *mech_data,
-				 const char *input,
-				 size_t input_len,
-				 char *output, size_t * output_len)
-{
-  _Gsasl_digest_md5_server_state *state = mech_data;
-
-  if (state == NULL || state->step != 3)
+  else
     {
       *output_len = input_len;
       if (output)
@@ -2204,11 +2188,23 @@ _gsasl_digest_md5_server_decode (Gsasl_session_ctx * xctx,
       return GSASL_OK;
     }
 
-  if (state->qop & GSASL_QOP_AUTH_CONF)
-    {
+  return GSASL_OK;
+}
 
+int
+_gsasl_digest_md5_server_decode (Gsasl_session_ctx * sctx,
+				 void *mech_data,
+				 const char *input,
+				 size_t input_len,
+				 char *output, size_t * output_len)
+{
+  _Gsasl_digest_md5_server_state *state = mech_data;
+
+  if (state && state->step == 3 && state->qop & GSASL_QOP_AUTH_CONF)
+    {
+      /* XXX */
     }
-  else if (state->qop & GSASL_QOP_AUTH_INT)
+  else if (state && state->step == 3 && state->qop & GSASL_QOP_AUTH_INT)
     {
       GCRY_MD_HD md5h;
       char *hash;
@@ -2265,6 +2261,14 @@ _gsasl_digest_md5_server_decode (Gsasl_session_ctx * xctx,
 
       gcry_md_close (md5h);
     }
+  else
+    {
+      *output_len = input_len;
+      if (output)
+	memcpy (output, input, input_len);
+      return GSASL_OK;
+    }
+
 
   return GSASL_OK;
 }
