@@ -32,7 +32,7 @@ extern "C" {
 #endif
 #endif
 
-#define GSASL_VERSION "0.0.4"
+#define GSASL_VERSION "0.0.5"
 
 /* Quoting RFC 2222:
    SASL mechanisms are named by strings, from 1 to 20 characters in
@@ -92,23 +92,21 @@ enum {
 };
 
 /* Quality of Protection types, used by DIGEST-MD5 */
-enum Gsasl_qop {
+typedef enum {
   GSASL_QOP_AUTH = 1,
   GSASL_QOP_AUTH_INT = 2,
   GSASL_QOP_AUTH_CONF = 4
-};
-typedef enum Gsasl_qop Gsasl_qop;
+} Gsasl_qop;
 
 /* Cipher types, used by DIGEST-MD5 */
-enum Gsasl_cipher {
+typedef enum {
   GSASL_CIPHER_DES = 1,
   GSASL_CIPHER_3DES = 2,
   GSASL_CIPHER_RC4 = 4,
   GSASL_CIPHER_RC4_40 = 8,
   GSASL_CIPHER_RC4_56 = 16,
   GSASL_CIPHER_AES = 32
-};
-typedef enum Gsasl_cipher Gsasl_cipher;
+} Gsasl_cipher;
 
 /* Library handles */
 typedef struct Gsasl_ctx Gsasl_ctx;
@@ -137,31 +135,31 @@ extern const char *gsasl_server_suggest_mechanism (Gsasl_ctx *ctx,
 
 /* Authentication functions: xstart.c, xstep.c, xfinish.c */
 extern int gsasl_client_start (Gsasl_ctx *ctx, const char *mech,
-			       Gsasl_session_ctx **cctx);
-extern int gsasl_client_step (Gsasl_session_ctx *xctx,
+			       Gsasl_session_ctx **sctx);
+extern int gsasl_client_step (Gsasl_session_ctx *sctx,
 			      const char *input, size_t input_len,
 			      char *output, size_t *output_len);
-extern int gsasl_client_step_base64 (Gsasl_session_ctx *xctx,
+extern int gsasl_client_step_base64 (Gsasl_session_ctx *sctx,
 				     const char *b64input,
 				     char *b64output,
 				     size_t b64output_len);
-extern void gsasl_client_finish (Gsasl_session_ctx *xctx);
+extern void gsasl_client_finish (Gsasl_session_ctx *sctx);
 extern int gsasl_server_start (Gsasl_ctx *ctx, const char *mech,
 			       Gsasl_session_ctx **sctx);
-extern int gsasl_server_step (Gsasl_session_ctx *xctx,
+extern int gsasl_server_step (Gsasl_session_ctx *sctx,
 			      const char *input, size_t input_len,
 			      char *output, size_t *output_len);
-extern int gsasl_server_step_base64 (Gsasl_session_ctx *xctx,
+extern int gsasl_server_step_base64 (Gsasl_session_ctx *sctx,
 				     const char *b64input,
 				     char *b64output,
 				     size_t b64output_len);
-extern void gsasl_server_finish (Gsasl_session_ctx *xctx);
+extern void gsasl_server_finish (Gsasl_session_ctx *sctx);
 
 /* Session functions: xcode.c */
-extern int gsasl_encode (Gsasl_session_ctx *xctx,
+extern int gsasl_encode (Gsasl_session_ctx *sctx,
 			 const char *input, size_t input_len,
 			 char *output, size_t *output_len);
-extern int gsasl_decode (Gsasl_session_ctx *xctx,
+extern int gsasl_decode (Gsasl_session_ctx *sctx,
 			 const char *input, size_t input_len,
 			 char *output, size_t *output_len);
 
@@ -183,86 +181,86 @@ extern int gsasl_md5pwd_get_password (const char *filename,
 				      size_t *keylen);
 
 /* Callback prototypes */
-typedef int (*Gsasl_client_callback_anonymous) (Gsasl_session_ctx *ctx,
+typedef int (*Gsasl_client_callback_anonymous) (Gsasl_session_ctx *sctx,
 						char *out,
 						size_t *outlen);
-typedef int (*Gsasl_client_callback_authentication_id) (Gsasl_session_ctx *ctx,
+typedef int (*Gsasl_client_callback_authentication_id) (Gsasl_session_ctx *sctx,
 							char *out,
 							size_t *outlen);
-typedef int (*Gsasl_client_callback_authorization_id) (Gsasl_session_ctx *ctx,
+typedef int (*Gsasl_client_callback_authorization_id) (Gsasl_session_ctx *sctx,
 						       char *out,
 						       size_t *outlen);
-typedef int (*Gsasl_client_callback_password) (Gsasl_session_ctx *ctx,
+typedef int (*Gsasl_client_callback_password) (Gsasl_session_ctx *sctx,
 					       char *out,
 					       size_t *outlen);
-typedef int (*Gsasl_client_callback_passcode) (Gsasl_session_ctx *ctx,
+typedef int (*Gsasl_client_callback_passcode) (Gsasl_session_ctx *sctx,
 					       char *out,
 					       size_t *outlen);
-typedef int (*Gsasl_client_callback_pin) (Gsasl_session_ctx *ctx,
+typedef int (*Gsasl_client_callback_pin) (Gsasl_session_ctx *sctx,
 					  char *suggestion,
 					  char *out,
 					  size_t *outlen);
-typedef int (*Gsasl_client_callback_service) (Gsasl_session_ctx *ctx,
+typedef int (*Gsasl_client_callback_service) (Gsasl_session_ctx *sctx,
 					      char *service,
 					      size_t *servicelen,
 					      char *hostname,
 					      size_t *hostnamelen,
 					      char *servicename,
 					      size_t *servicenamelen);
-typedef Gsasl_qop (*Gsasl_client_callback_qop) (Gsasl_session_ctx *ctx,
+typedef Gsasl_qop (*Gsasl_client_callback_qop) (Gsasl_session_ctx *sctx,
 						Gsasl_qop serverqops);
-typedef int (*Gsasl_client_callback_maxbuf) (Gsasl_session_ctx *ctx,
+typedef int (*Gsasl_client_callback_maxbuf) (Gsasl_session_ctx *sctx,
 					     int servermaxbuf);
-typedef int (*Gsasl_server_callback_retrieve) (Gsasl_session_ctx *ctx,
+typedef int (*Gsasl_server_callback_retrieve) (Gsasl_session_ctx *sctx,
 					       const char *authentication_id,
 					       const char *authorization_id,
 					       const char *realm,
 					       char *key,
 					       size_t *keylen);
-typedef int (*Gsasl_server_callback_validate) (Gsasl_session_ctx *ctx,
+typedef int (*Gsasl_server_callback_validate) (Gsasl_session_ctx *sctx,
 					       const char *authorization_id,
 					       const char *authentication_id,
 					       const char *password);
-typedef int (*Gsasl_server_callback_gssapi) (Gsasl_session_ctx *ctx,
+typedef int (*Gsasl_server_callback_gssapi) (Gsasl_session_ctx *sctx,
 					     const char *clientname,
 					     const char *authentication_id);
-typedef int (*Gsasl_server_callback_securid) (Gsasl_session_ctx *ctx,
+typedef int (*Gsasl_server_callback_securid) (Gsasl_session_ctx *sctx,
 					      const char *authentication_id,
 					      const char *authorization_id,
 					      const char *passcode,
 					      char *pin,
 					      char *suggestpin,
 					      size_t *suggestpinlen);
-typedef int (*Gsasl_server_callback_cram_md5) (Gsasl_session_ctx *ctx,
+typedef int (*Gsasl_server_callback_cram_md5) (Gsasl_session_ctx *sctx,
 					       char *username,
 					       char *challenge,
 					       char *response);
-typedef int (*Gsasl_server_callback_digest_md5) (Gsasl_session_ctx *ctx,
+typedef int (*Gsasl_server_callback_digest_md5) (Gsasl_session_ctx *sctx,
 						 char *username,
 						 char *realm,
 						 char *secrethash);
-typedef int (*Gsasl_server_callback_service) (Gsasl_session_ctx *ctx,
+typedef int (*Gsasl_server_callback_service) (Gsasl_session_ctx *sctx,
 					      char *service,
 					      size_t *servicelen,
 					      char *hostname,
 					      size_t *hostnamelen);
-typedef int (*Gsasl_server_callback_external) (Gsasl_session_ctx *ctx);
-typedef int (*Gsasl_server_callback_anonymous) (Gsasl_session_ctx *ctx,
+typedef int (*Gsasl_server_callback_external) (Gsasl_session_ctx *sctx);
+typedef int (*Gsasl_server_callback_anonymous) (Gsasl_session_ctx *sctx,
 						const char *token);
-typedef int (*Gsasl_server_callback_realm) (Gsasl_session_ctx *ctx,
+typedef int (*Gsasl_server_callback_realm) (Gsasl_session_ctx *sctx,
 					    char *out,
 					    size_t *outlen,
 					    size_t nth);
-typedef Gsasl_qop (*Gsasl_server_callback_qop) (Gsasl_session_ctx *ctx);
-typedef int (*Gsasl_server_callback_maxbuf) (Gsasl_session_ctx *ctx);
-typedef Gsasl_cipher (*Gsasl_server_callback_cipher) (Gsasl_session_ctx *ctx);
+typedef Gsasl_qop (*Gsasl_server_callback_qop) (Gsasl_session_ctx *sctx);
+typedef int (*Gsasl_server_callback_maxbuf) (Gsasl_session_ctx *sctx);
+typedef Gsasl_cipher (*Gsasl_server_callback_cipher) (Gsasl_session_ctx *sctx);
 
 /* Client callbacks */
-extern Gsasl_ctx *gsasl_client_ctx_get (Gsasl_session_ctx *cctx);
+extern Gsasl_ctx *gsasl_client_ctx_get (Gsasl_session_ctx *sctx);
 
-extern void gsasl_client_application_data_set (Gsasl_session_ctx *xctx,
+extern void gsasl_client_application_data_set (Gsasl_session_ctx *sctx,
 					       void *application_data);
-extern void *gsasl_client_application_data_get (Gsasl_session_ctx *ctx);
+extern void *gsasl_client_application_data_get (Gsasl_session_ctx *sctx);
 
 extern void gsasl_client_callback_authorization_id_set (Gsasl_ctx *ctx,
 				Gsasl_client_callback_authorization_id cb);
@@ -312,9 +310,9 @@ extern Gsasl_client_callback_maxbuf
 /* Server callbacks */
 extern Gsasl_ctx *gsasl_server_ctx_get (Gsasl_session_ctx *sctx);
 
-extern void gsasl_server_application_data_set (Gsasl_session_ctx *xctx,
+extern void gsasl_server_application_data_set (Gsasl_session_ctx *sctx,
 					       void *application_data);
-extern void *gsasl_server_application_data_get (Gsasl_session_ctx *ctx);
+extern void *gsasl_server_application_data_get (Gsasl_session_ctx *sctx);
 
 extern void gsasl_server_callback_validate_set (Gsasl_ctx *ctx,
 				     Gsasl_server_callback_validate cb);
