@@ -1,20 +1,20 @@
 /* simple.c	test the simple SASL mechanisms
  * Copyright (C) 2002  Simon Josefsson
  *
- * This file is part of libgsasl.
+ * This file is part of GNU SASL.
  *
- * Libgsasl is free software; you can redistribute it and/or modify
+ * GNU SASL is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  *
- * Libgsasl is distributed in the hope that it will be useful,
+ * GNU SASL is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with libgsasl; if not, write to the Free Software
+ * along with GNU SASL; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  */
@@ -410,6 +410,9 @@ client_callback_pin (Gsasl_session_ctx * xctx, char *suggestion,
       (suggestion != NULL && sasltv[i].suggestpin == NULL))
     return GSASL_AUTHENTICATION_ERROR;
 
+  if (*outlen < strlen (sasltv[i].pin))
+    return GSASL_TOO_SMALL_BUFFER;
+
   *outlen = strlen (sasltv[i].pin);
   if (out)
     memcpy (out, sasltv[i].pin, strlen (sasltv[i].pin));
